@@ -82,9 +82,20 @@ app.add_typer(cloud_app, name="cloud", help="Interact with a Calkit Cloud.")
 app.add_typer(slurm_app, name="slurm", help="Work with SLURM.")
 
 # Constants for version control auto-ignore
-AUTO_IGNORE_SUFFIXES = [".DS_Store", ".env", ".pyc", ".synctex.gz"]
+AUTO_IGNORE_SUFFIXES = [
+    ".DS_Store",
+    ".env",
+    ".pyc",
+    ".synctex.gz",
+    ".ipynb_checkpoints",
+]
 AUTO_IGNORE_PATHS = [os.path.join(".dvc", "config.local")]
-AUTO_IGNORE_PREFIXES = [".venv", "__pycache__"]
+AUTO_IGNORE_PREFIXES = [
+    ".venv",
+    "__pycache__",
+    ".ipynb_checkpoints",
+    ".calkit/overleaf/",
+]
 # Constants for version control auto-add to DVC
 DVC_EXTENSIONS = [
     ".png",
